@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import os
+import warnings
 from pathlib import Path
 from ruamel.yaml import YAML
 from datetime import date
@@ -630,7 +631,7 @@ class PathConfigAllSkyTraining(PathConfigAllSkyBase):
                     'input': dl1,
                     'output': merged_dl1,
                     'options': '--pattern */*.h5 --no-image',
-                    'slurm_options': '-p long',
+                    'extra_slurm_options': {'partition': 'long'},
                 }
             )
         return paths
@@ -644,8 +645,12 @@ class PathConfigAllSkyTraining(PathConfigAllSkyBase):
                     'proton': self.training_merged_dl1('Protons'),
                 },
                 'output': self.models_dir(),
-                'slurm_options': '-p xxl --mem=160G --cpus-per-task=16' if self.dec == _crab_dec
-                else '-p xxl --mem=100G --cpus-per-task=16',
+                'extra_slurm_options': {'partition': 'xxl',
+                                        'mem': '160G',
+                                        'cpus-per-task': 16} if self.dec == _crab_dec
+                else {'partition': 'xxl',
+                      'mem': '100G',
+                      'cpus-per-task': 16}
             }
         ]
         return paths
@@ -793,7 +798,7 @@ class PathConfigAllSkyTesting(PathConfigAllSkyBase):
                     'input': self.testing_merged_dl1(pointing),
                     'path_model': self.models_dir(),
                     'output': self.dl2_dir(pointing),
-                    'slurm_options': '--mem=80GB' if self.dec == _crab_dec else '--mem=60GB'
+                    'extra_slurm_options': {'mem': '80GB' if self.dec == _crab_dec else '60GB'}
                 }
             )
         return paths
@@ -816,7 +821,7 @@ class PathConfigAllSkyTesting(PathConfigAllSkyBase):
                     },
                     'output': os.path.join(self.irf_dir(pointing), f'irf_{self.prod_id}_{pointing}.fits.gz'),
                     'options': '--point-like',
-                    'slurm_options': '--mem=6GB'
+                    'extra_slurm_options': {'mem':'6GB'}
                 }
             )
 
@@ -935,11 +940,15 @@ class PathConfigAllSkyTrainingDL1ab(PathConfigAllSkyTraining):
             self.check_source_prod()
         
     def check_source_prod(self):
+        marked_for_removal = []
         for particle in self.training_particles:
-            for pointing in self.pointing_dirs(particle):
+            for pidx, pointing in enumerate(self.pointing_dirs(particle)):
                 source_dl1 = Path(self.source_config.dl1_dir(particle, pointing))
                 if not source_dl1.exists():
-                    raise FileNotFoundError(f"{source_dl1} should exist to run this DL1ab")
+                    warnings.warn(f"{source_dl1} does not exist but MC file for {particle} - {pointing} does. "
+                                  f"This node will be removed from production.")
+                    marked_for_removal.append(pidx)
+        self._training_pointings.remove_rows(pidx)
 
     @property
     def dl1ab(self):
@@ -976,10 +985,14 @@ class PathConfigAllSkyTestingDL1ab(PathConfigAllSkyTesting):
             self.check_source_prod()
         
     def check_source_prod(self):
-        for pointing in self.pointing_dirs():
+        marked_for_removal = []
+        for pidx, pointing in enumerate(self.pointing_dirs()):
             source_dl1 = Path(self.source_config.dl1_dir(pointing))
             if not source_dl1.exists():
-                raise FileNotFoundError(f"{source_dl1} should exist to run this DL1ab")
+                warnings.warn(f"{source_dl1} does not exist but MC file for {pointing} does. "
+                              f"This node will be removed from production.")
+                marked_for_removal.append(pidx)
+        self._testing_pointings.remove_rows(marked_for_removal)
 
     @property
     def dl1ab(self):
