@@ -1,6 +1,7 @@
 """
 Run python rerun_irfs_mem_issue.py lstmcpipe_config.yaml
 """
+
 from ruamel.yaml import YAML
 import sys
 from pathlib import Path
@@ -22,14 +23,14 @@ to_rerun = []
 for p in cfg['stages']['dl2_to_irfs']:
     if not Path(p['output']).is_file():
         print(p['output'])
-        p['slurm_options'] = '--mem=6GB'
+        p['extra_slurm_options'] = {'mem':'6GB'}
         to_rerun.append(p)
 
 cfg['stages']['dl2_to_irfs'] = to_rerun
 print(f"{len(to_rerun)} irfs to re-produce")
 
 
-output_filename = filename.parent.joinpath(filename.stem + '_rerun.yaml')
+output_filename = filename.parent.joinpath(f'{filename.stem}_rerun.yaml')
 
 if to_rerun and not Path(output_filename).exists():
     print(f"Run lstmcpipe -c {output_filename}")
