@@ -11,14 +11,7 @@ from ..io.data_management import check_data_path, get_input_filelist
 log = logging.getLogger(__name__)
 
 
-def batch_process_dl1(
-    dict_paths,
-    conf_file,
-    batch_config,
-    logs,
-    workflow_kind="lstchain",
-    new_production=True,
-):
+def batch_process_dl1(dict_paths, conf_file, batch_config, logs, workflow_kind="lstchain", new_production=True):
     """
     Batch the dl1 processing jobs by particle type.
 
@@ -46,33 +39,28 @@ def batch_process_dl1(
     log_process_dl1 = {}
     debug_log = {}
     jobids_dl1_processing_stage = []
-
-    log.info("==== START {} dl1 processing ====".format(workflow_kind))
-
+    log.info(f"==== START {workflow_kind} dl1 processing ====")
     if new_production:
-
         for paths in dict_paths["r0_to_dl1"]:
-
             try:
                 check_data_path(paths["input"], glob="*.simtel.gz")
             except ValueError:
                 debug_log["**EMPTY_R0_DIR**"] = f'{paths["input"]} directory does not contain any simtel.gz file'
-                continue
 
+                continue
             job_logs, jobid = r0_to_dl1(
                 paths["input"],
                 paths["output"],
                 config_file=conf_file,
                 batch_config=batch_config,
                 workflow_kind=workflow_kind,
-                slurm_options=paths.get("slurm_options", None),
+                extra_slurm_options=paths.get("extra_slurm_options", None),
             )
+
             log_process_dl1.update(job_logs)
             jobids_dl1_processing_stage.append(jobid)
             debug_log[jobid] = f'r0_dl1 job from input dir: {paths["input"]}'
-
     else:
-
         for paths in dict_paths["dl1ab"]:
             job_logs, jobid = reprocess_dl1(
                 paths["input"],
@@ -80,21 +68,16 @@ def batch_process_dl1(
                 config_file=conf_file,
                 batch_config=batch_config,
                 workflow_kind=workflow_kind,
-                slurm_options=paths.get("slurm_options", None),
+                extra_slurm_options=paths.get("extra_slurm_options", None),
             )
 
             log_process_dl1.update(job_logs)
             jobids_dl1_processing_stage.append(jobid)
             debug_log[jobid] = f'dl1ab job from input dir: {paths["input"]}'
-
-    # Create a string to be directly passed
     jobids_dl1_processing_stage = ",".join(jobids_dl1_processing_stage)
-
     save_log_to_file(log_process_dl1, logs["log_file"], "r0_to_dl1")
     save_log_to_file(debug_log, logs["debug_file"], workflow_step="r0_to_dl1")
-
-    log.info("==== END {} dl1 processing ====".format(workflow_kind))
-
+    log.info(f"==== END {workflow_kind} dl1 processing ====")
     return jobids_dl1_processing_stage
 
 
@@ -106,7 +89,7 @@ def r0_to_dl1(
     batch_config=None,
     debug_mode=False,
     keep_rta_file=False,
-    slurm_options=None,
+    extra_slurm_options=None,
 ):
     """
     R0 to DL1 MC onsite conversion.
@@ -126,7 +109,7 @@ def r0_to_dl1(
         ! NOTE : train_pipe AND dl1_to_dl2 **MUST** be run with the same environment.
     workflow_kind: str
         One of the supported pipelines. Defines the command to be run on r0 files
-    slurm_options: str
+    extra_slurm_options: dict
         Extra slurm options to be passed
 
     # HIPERTA ARGUMENTS
@@ -145,9 +128,7 @@ def r0_to_dl1(
     jobids_r0_dl1
         A list of all the jobs sent for input dir
     """
-
-    log.info("\nStarting R0 to DL1 processing for files in dir : {}".format(input_dir))
-
+    log.info(f'\nStarting R0 to DL1 processing for files in dir : {input_dir}')
     if workflow_kind == "lstchain":
         base_cmd = f"lstmcpipe_lst_core_r0_dl1 -c {config_file} "
         jobtype_id = "LST"
@@ -160,38 +141,25 @@ def r0_to_dl1(
             base_cmd += " --keep_rta_file"
         if debug_mode:
             base_cmd += " --debug_mode"
-
         jobtype_id = "RTA"
     else:
         base_cmd = ''
         jobtype_id = ''
         log.critical("Please, select an allowed workflow kind.")
         exit(-1)
-
     raw_files_list = get_input_filelist(input_dir, glob_pattern="*.simtel.gz")
-
-    if len(raw_files_list) < 50:
-        dl1_files_per_job = 20
-    else:
-        dl1_files_per_job = 50
-
+    dl1_files_per_job = 20 if len(raw_files_list) < 50 else 50
     with open("r0_to_dl1.list", "w+") as newfile:
         for f in raw_files_list:
             newfile.write(f)
             newfile.write("\n")
-
-    log.info("{} raw R0 files".format(len(raw_files_list)))
-
-    # If file exists, means that prod is being re-run
+    log.info(f"{len(raw_files_list)} raw R0 files")
     output_dir = Path(output_dir)
     if output_dir.exists() and any(output_dir.iterdir()):
         shutil.rmtree(output_dir)
-
     job_logs_dir = output_dir.joinpath("job_logs_r0dl1")
     Path(job_logs_dir).mkdir(exist_ok=True, parents=True)
-
-    log.info("DL1 DATA DIR: {}".format(output_dir))
-
+    log.info(f"DL1 DATA DIR: {output_dir}")
     jobid2log, jobids_r0_dl1 = submit_dl1_jobs(
         input_dir,
         output_dir,
@@ -202,17 +170,12 @@ def r0_to_dl1(
         job_logs_dir=job_logs_dir,
         batch_config=batch_config,
         dl1_processing_type="r0_to_dl1",
-        slurm_options=slurm_options,
+        extra_slurm_options=extra_slurm_options,
     )
 
-    # copy config into working dir
     if config_file is not None:
         shutil.copyfile(config_file, job_logs_dir.joinpath(Path(config_file).name))
-
-    # save file lists into logs
     shutil.move("r0_to_dl1.list", job_logs_dir)
-
-    # return it log dictionary
     return jobid2log, jobids_r0_dl1
 
 
@@ -223,7 +186,7 @@ def reprocess_dl1(
     config_file=None,
     batch_config=None,
     dl1_files_per_job=50,
-    slurm_options=None,
+    extra_slurm_options=None,
 ):
     """
     Reprocessing of existing dl1 files.
@@ -246,7 +209,7 @@ def reprocess_dl1(
         One of the supported pipelines. Defines the command to be run on r0 files
     dl1_files_per_job: int
         Number of dl1 files to be processed per job array that was batched.
-    slurm_options: str
+    extra_slurm_options: dict
         Extra slurm options to be passed to the sbatch command
 
     Returns
@@ -256,8 +219,7 @@ def reprocess_dl1(
     jobids_dl1_dl1
         A list of all the jobs sent for input dir
     """
-    log.info("Applying DL1ab on DL1 files in {}".format(input_dir))
-
+    log.info(f"Applying DL1ab on DL1 files in {input_dir}")
     if workflow_kind == "lstchain":
         base_cmd = f"lstmcpipe_lst_core_dl1ab -c {config_file} "
         jobtype_id = "LST"
@@ -269,23 +231,18 @@ def reprocess_dl1(
         jobtype_id = ""
         log.critical(f"Unknown workflow {workflow_kind}")
         exit(-1)
-
     check_data_path(input_dir)
     dl1ab_filelist = [file.resolve().as_posix() for file in Path(input_dir).glob("*.h5")]
 
-    log.info("{} DL1 files".format(len(dl1ab_filelist)))
-
+    log.info(f"{len(dl1ab_filelist)} DL1 files")
     with open("dl1ab.list", "w+") as newfile:
         for f in dl1ab_filelist:
             newfile.write(f)
             newfile.write("\n")
-
     Path(output_dir).mkdir(exist_ok=True, parents=True)
     job_logs_dir = Path(output_dir).joinpath("job_logs_dl1ab")
     Path(job_logs_dir).mkdir(exist_ok=True)
-
-    log.info("DL1ab destination DATA DIR: {}".format(output_dir))
-
+    log.info(f"DL1ab destination DATA DIR: {output_dir}")
     jobid2log, jobids_dl1_dl1 = submit_dl1_jobs(
         input_dir,
         output_dir,
@@ -296,17 +253,12 @@ def reprocess_dl1(
         job_logs_dir=job_logs_dir,
         batch_config=batch_config,
         dl1_processing_type="dl1ab",
-        slurm_options=slurm_options,
+        extra_slurm_options=extra_slurm_options,
     )
 
-    # copy config into working dir
     if config_file is not None:
         shutil.copyfile(config_file, job_logs_dir.joinpath(Path(config_file).name))
-
-    # save file lists into logs
     shutil.move("dl1ab.list", job_logs_dir)
-
-    # return it log dictionary
     return jobid2log, jobids_dl1_dl1
 
 
@@ -321,7 +273,7 @@ def submit_dl1_jobs(
     batch_config,
     n_jobs_parallel=100,
     dl1_processing_type="r0_to_dl1",
-    slurm_options="",
+    extra_slurm_options=None,
 ):
     """
     Compose sbatch command and batches it
@@ -351,7 +303,7 @@ def submit_dl1_jobs(
         Default = 100
     dl1_processing_type: str
         String for job and filelist naming
-    slurm_options: str
+    extra_slurm_options: dict
         Extra slurm options to be passed
 
     Returns
@@ -360,52 +312,37 @@ def submit_dl1_jobs(
     jobid: str
 
     """
-    jobid2log = {}
-
     number_of_sublists = len(file_list) // dl1_files_per_batched_job + int(
         len(file_list) % dl1_files_per_batched_job > 0
     )
 
     for i in range(number_of_sublists):
-        output_file = job_logs_dir.joinpath("{}_{}.sublist".format(dl1_processing_type, i)).resolve().as_posix()
+        output_file = job_logs_dir.joinpath(f"{dl1_processing_type}_{i}.sublist").resolve().as_posix()
+
         with open(output_file, "w+") as out:
-            for line in file_list[i * dl1_files_per_batched_job : dl1_files_per_batched_job * (i + 1)]:  # noqa
+            for line in file_list[i * dl1_files_per_batched_job:dl1_files_per_batched_job * (i + 1)]:
                 out.write(line)
                 out.write("\n")
-
     log.info(f"{number_of_sublists} files generated for list of files at {input_dir}")
 
-    sublist_names = [f.as_posix() for f in Path(job_logs_dir).glob("*.sublist")]  # Number of sublists ??
-
-    # start 1 jobarray with all files included. The job selects its file based on its task id
+    sublist_names = [f.as_posix() for f in Path(job_logs_dir).glob("*.sublist")]
     cmd = f'{base_cmd} -f {" ".join(sublist_names)} --output_dir {output_dir}'
+    extra_slurm_default_options = {'partition': 'long', 'array': f"0-{len(sublist_names) - 1}%{n_jobs_parallel}"}
 
+    if extra_slurm_options is not None:
+        extra_slurm_default_options.update(extra_slurm_options)
     sbatch_process_dl1 = SbatchLstMCStage(
         dl1_processing_type,
         wrap_command=cmd,
+        job_name=f"{job_type_id}-{dl1_processing_type}",
         slurm_error=job_logs_dir.joinpath("job_%A_%a.e").as_posix(),
         slurm_output=job_logs_dir.joinpath("job_%A_%a.o").as_posix(),
         slurm_account=batch_config["slurm_account"],
         source_environment=batch_config["source_environment"],
+        extra_slurm_options=extra_slurm_default_options,
     )
-    if dl1_processing_type == "r0_to_dl1":
-        sbatch_process_dl1.r0_dl1_options(
-            process_dl1_job_name=f"{job_type_id}-{dl1_processing_type}",
-            array=f"0-{len(sublist_names) - 1}%{n_jobs_parallel}",
-            partition="long",
-            extra_slurm_options="",
-        )
-    elif dl1_processing_type == "dl1ab":
-        sbatch_process_dl1.dl1ab_options(
-            process_dl1ab_job_name=f"{job_type_id}-{dl1_processing_type}",
-            array=f"0-{len(sublist_names) - 1}%{n_jobs_parallel}",
-            partition="long",
-            extra_slurm_options="",
-        )
 
     jobid = sbatch_process_dl1.submit()
     log.debug(f"Submitted batch job {jobid}")
-
-    jobid2log.update({jobid: sbatch_process_dl1.slurm_command})
-
+    jobid2log = {jobid: sbatch_process_dl1.slurm_command}
     return jobid2log, jobid
